@@ -7,6 +7,16 @@ from nexustrader.exchange.binance.connector import (
 from nexustrader.exchange.binance.rest_api import BinanceApiClient
 from nexustrader.exchange.binance.ems import BinanceExecutionManagementSystem
 from nexustrader.exchange.binance.oms import BinanceOrderManagementSystem
+from nexustrader.exchange.binance.factory import BinanceFactory
+
+# Auto-register factory on import
+try:
+    from nexustrader.exchange.registry import register_factory
+
+    register_factory(BinanceFactory())
+except ImportError:
+    # Registry not available yet during bootstrap
+    pass
 
 __all__ = [
     "BinanceAccountType",
@@ -17,4 +27,5 @@ __all__ = [
     "BinanceApiClient",
     "BinanceExecutionManagementSystem",
     "BinanceOrderManagementSystem",
+    "BinanceFactory",
 ]
