@@ -1,10 +1,10 @@
 import hmac
 import hashlib
 import msgspec
-import httpx
 
 from typing import Any, Dict
 from urllib.parse import urljoin, urlencode
+from curl_cffi import requests
 
 from nexustrader.base import ApiClient, RetryManager
 from nexustrader.exchange.binance.schema import (
@@ -169,16 +169,16 @@ class BinanceApiClient(ApiClient):
                     message=error_msg.get("msg", "Unknown error"),
                 )
             return raw
-        except httpx.TimeoutException as e:
+        except requests.exceptions.Timeout as e:
             self._log.error(f"Timeout {method} {url} {e}")
             raise
-        except httpx.ConnectError as e:
+        except requests.exceptions.ConnectionError as e:
             self._log.error(f"Connection Error {method} {url} {e}")
             raise
-        except httpx.HTTPStatusError as e:
+        except requests.exceptions.HTTPError as e:
             self._log.error(f"HTTP Error {method} {url} {e}")
             raise
-        except httpx.RequestError as e:
+        except requests.exceptions.RequestException as e:
             self._log.error(f"Request Error {method} {url} {e}")
             raise
         except Exception as e:
@@ -248,16 +248,16 @@ class BinanceApiClient(ApiClient):
                     message=error_msg.get("msg", "Unknown error"),
                 )
             return raw
-        except httpx.TimeoutException as e:
+        except requests.exceptions.Timeout as e:
             self._log.error(f"Timeout {method} {url} {e}")
             raise
-        except httpx.ConnectError as e:
+        except requests.exceptions.ConnectionError as e:
             self._log.error(f"Connection Error {method} {url} {e}")
             raise
-        except httpx.HTTPStatusError as e:
+        except requests.exceptions.HTTPError as e:
             self._log.error(f"HTTP Error {method} {url} {e}")
             raise
-        except httpx.RequestError as e:
+        except requests.exceptions.RequestException as e:
             self._log.error(f"Request Error {method} {url} {e}")
             raise
         except Exception as e:
