@@ -1,5 +1,3 @@
-import random
-import string
 from datetime import timedelta
 from throttled.asyncio import Throttled, rate_limiter
 from throttled import Throttled as ThrottledSync
@@ -461,18 +459,3 @@ class BybitRateLimiterSync(RateLimiterSync):
 
     def __call__(self, rate_limit_type: str) -> ThrottledSync:
         return self._throttled[rate_limit_type]
-
-
-def strip_uuid_hyphens(uuid_str: str) -> str:
-    """Remove hyphens from UUID string for OKX API compatibility."""
-    stripped = uuid_str.replace("-", "")
-    random_suffix = "".join(random.choices(string.ascii_letters + string.digits, k=4))
-    return stripped + random_suffix
-
-
-def restore_uuid_hyphens(uuid_str: str) -> str:
-    """Restore hyphens to UUID string from OKX API response."""
-    uuid_str = uuid_str[:-4]
-    if len(uuid_str) != 32:
-        return uuid_str  # Return as-is if not a valid stripped UUID
-    return f"{uuid_str[:8]}-{uuid_str[8:12]}-{uuid_str[12:16]}-{uuid_str[16:20]}-{uuid_str[20:]}"
