@@ -1,9 +1,9 @@
 import hmac
 import hashlib
-import httpx
 import msgspec
 from typing import Any, Dict, List
 from urllib.parse import urljoin, urlencode
+from curl_cffi import requests
 from decimal import Decimal
 from nexustrader.base import ApiClient, RetryManager
 from nexustrader.exchange.bybit.constants import (
@@ -212,16 +212,16 @@ class BybitApiClient(ApiClient):
                     code=bybit_response.retCode,
                     message=bybit_response.retMsg,
                 )
-        except httpx.TimeoutException as e:
+        except requests.exceptions.Timeout as e:
             self._log.error(f"Timeout {method} Url: {url} - {e}")
             raise
-        except httpx.ConnectError as e:
+        except requests.exceptions.ConnectionError as e:
             self._log.error(f"Connection Error {method} Url: {url} - {e}")
             raise
-        except httpx.HTTPStatusError as e:
+        except requests.exceptions.HTTPError as e:
             self._log.error(f"HTTP Error {method} Url: {url} - {e}")
             raise
-        except httpx.RequestError as e:
+        except requests.exceptions.RequestException as e:
             self._log.error(f"Request Error {method} Url: {url} - {e}")
             raise
         except Exception as e:
@@ -283,16 +283,16 @@ class BybitApiClient(ApiClient):
                     code=bybit_response.retCode,
                     message=bybit_response.retMsg,
                 )
-        except httpx.TimeoutException as e:
+        except requests.exceptions.Timeout as e:
             self._log.error(f"Timeout {method} Url: {url} - {e}")
             raise
-        except httpx.ConnectError as e:
+        except requests.exceptions.ConnectionError as e:
             self._log.error(f"Connection Error {method} Url: {url} - {e}")
             raise
-        except httpx.HTTPStatusError as e:
+        except requests.exceptions.HTTPError as e:
             self._log.error(f"HTTP Error {method} Url: {url} - {e}")
             raise
-        except httpx.RequestError as e:
+        except requests.exceptions.RequestException as e:
             self._log.error(f"Request Error {method} Url: {url} - {e}")
             raise
         except Exception as e:
