@@ -1,10 +1,10 @@
-import httpx
 import msgspec
 import eth_account
 from eth_account.signers.local import LocalAccount
 from eth_account.messages import encode_typed_data
 from typing import Dict, Any, List, Literal
 from urllib.parse import urljoin
+from curl_cffi import requests
 from Crypto.Hash import keccak
 
 from nexustrader.base.api_client import ApiClient
@@ -126,16 +126,16 @@ class HyperLiquidApiClient(ApiClient):
                 )
 
             return raw
-        except httpx.TimeoutException as e:
+        except requests.exceptions.Timeout as e:
             self._log.error(f"Timeout {method} {url} {e}")
             raise
-        except httpx.ConnectError as e:
+        except requests.exceptions.ConnectionError as e:
             self._log.error(f"Connection Error {method} {url} {e}")
             raise
-        except httpx.HTTPStatusError as e:
+        except requests.exceptions.HTTPError as e:
             self._log.error(f"HTTP Error {method} {url} {e}")
             raise
-        except httpx.RequestError as e:
+        except requests.exceptions.RequestException as e:
             self._log.error(f"Request Error {method} {url} {e}")
             raise
         except Exception as e:
@@ -174,16 +174,16 @@ class HyperLiquidApiClient(ApiClient):
                 )
 
             return raw
-        except httpx.TimeoutException as e:
+        except requests.exceptions.Timeout as e:
             self._log.error(f"Timeout {method} {url} {e}")
             raise
-        except httpx.ConnectError as e:
+        except requests.exceptions.ConnectionError as e:
             self._log.error(f"Connection Error {method} {url} {e}")
             raise
-        except httpx.HTTPStatusError as e:
+        except requests.exceptions.HTTPError as e:
             self._log.error(f"HTTP Error {method} {url} {e}")
             raise
-        except httpx.RequestError as e:
+        except requests.exceptions.RequestException as e:
             self._log.error(f"Request Error {method} {url} {e}")
             raise
         except Exception as e:
