@@ -119,13 +119,13 @@ class OkxExecutionManagementSystem(ExecutionManagementSystem):
     async def _cancel_all_orders(
         self, order_submit: CancelAllOrderSubmit, account_type: AccountType
     ):
-        # override the base method
+        # override the base methods
         symbol = order_submit.symbol
-        uuids = self._cache.get_open_orders(symbol)
-        for uuid in uuids:
+        oids = self._cache.get_open_orders(symbol)
+        for oid in oids:
             order_submit = CancelOrderSubmit(
                 symbol=symbol,
                 instrument_id=InstrumentId.from_str(symbol),
-                uuid=uuid,
+                oid=oid,
             )
             await self._cancel_order(order_submit, account_type)
